@@ -15,18 +15,22 @@
 #' function only returning the probability of detection at that distance. In
 #' addition to the simple model above, we may specify adjustment terms to fit
 #' the data better. These adjustments are either Cosine, Hermite and simple
-#' polynomials.
-#' These are specified as arguments to \code{detfct}, as detailed below.
+#' polynomials. These are specified as arguments to \code{detfct}, as detailed
+#' below.
 #'
-#' \code{detfct} function which calls the others and assembles the final result using either key(x)[1+series(x)] or (key(x)[1+series(x)])/(key(0)[1+series(0)]) (depending on the value of \code{standardize}).
+#' \code{detfct} function which calls the others and assembles the final result
+#' using either key(x)[1+series(x)] or
+#' (key(x)[1+series(x)])/(key(0)[1+series(0)]) (depending on the value of
+#' \code{standardize}).
 #'
-#' \code{keyfct.*} functions calculate key function values and \code{adjfct.*} calculate adjustment term values.
+#' \code{keyfct.*} functions calculate key function values and \code{adjfct.*}
+#' calculate adjustment term values.
 #'
 #' \code{scalevalue} for either detection function it computes the scale with
 #' the log link using the parameters and the covariate design matrix
 #'
-#' \code{fx}, \code{fr} non-normalized probability density for line transects and point
-#' counts respectively
+#' \code{fx}, \code{fr} non-normalized probability density for line transects
+#' and point counts respectively
 #'
 #' @aliases detfct adjfct.cos adjfct.herm hermite.poly adjfct.poly keyfct.hn
 #'  keyfct.hz keyfct.gamma scalevalue fx fr distpdf
@@ -67,7 +71,8 @@
 #' @param adj.parm vector of adjustment parameters
 #' @param width (right) truncation width
 #' @param left (left) truncation distance
-#' @param standardize logical used to decide whether to divide through by the function evaluated at 0
+#' @param standardize logical used to decide whether to divide through by the
+#' function evaluated at 0
 #' @param scaling the scaling for the adjustment terms
 #' @param stdint logical used to decide whether integral is standardized
 #' @param point if TRUE, point counts; otherwise line transects
@@ -80,11 +85,16 @@
 #' @author Jeff Laake, David L Miller
 #' @seealso  \code{\link{mcds}},  \code{\link{cds}}
 #' @references
-#' Marques, F. F. C., & Buckland, S. T. (2003). Incorporating covariates into standard line transect analyses. Biometrics, 59(4), 924-935.
+#' Marques, F. F. C., & Buckland, S. T. (2003). Incorporating covariates into
+#' standard line transect analyses. Biometrics, 59(4), 924-935.
 #'
-#' Buckland, S. T., Anderson, D. R., Burnham, K. P., Laake, J. L., Borchers, D. L., & Thomas, L. (2004). Advanced Distance Sampling. Oxford University Press, Oxford, UK.
+#' Buckland, S. T., Anderson, D. R., Burnham, K. P., Laake, J. L., Borchers, D.
+#' L., & Thomas, L. (2004). Advanced Distance Sampling. Oxford University
+#' Press, Oxford, UK.
 #'
-#' Becker, E. F. and P. X. Quang. 2009. A gamma-shaped detection function for line transect surveys with mark-recapture and covariate data. Journal of Agricultural Biological and Environmental Statistics 14:207-223.
+#' Becker, E. F. and P. X. Quang. 2009. A gamma-shaped detection function for
+#' line transect surveys with mark-recapture and covariate data. Journal of
+#' Agricultural Biological and Environmental Statistics 14:207-223.
 #' @export detfct
 #' @keywords internal
 distpdf <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
@@ -125,18 +135,18 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
       shape.dm <- ddfobj$shape$dm
     }else{
       # use only those with specific indices
-      scale.dm <- ddfobj$scale$dm[index,,drop=FALSE]
-      shape.dm <- ddfobj$shape$dm[index,,drop=FALSE]
+      scale.dm <- ddfobj$scale$dm[index, , drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[index, , drop=FALSE]
     }
   }else{
     # Use those with select=TRUE
     if(is.null(index)){
-      scale.dm <- ddfobj$scale$dm[select,,drop=FALSE]
-      shape.dm <- ddfobj$shape$dm[select,,drop=FALSE]
+      scale.dm <- ddfobj$scale$dm[select, , drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[select, , drop=FALSE]
     }else{
       # use the numeric index within those with select=TRUE
-      scale.dm <- ddfobj$scale$dm[select,,drop=FALSE][index,,drop=FALSE]
-      shape.dm <- ddfobj$shape$dm[select,,drop=FALSE][index,,drop=FALSE]
+      scale.dm <- ddfobj$scale$dm[select, , drop=FALSE][index, , drop=FALSE]
+      shape.dm <- ddfobj$shape$dm[select, , drop=FALSE][index, , drop=FALSE]
     }
   }
 
@@ -146,19 +156,19 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
   # calculate the key scale
   if(stdint){
     if(is.null(index)){
-      key.scale <- rep(1,nrow(scale.dm))
+      key.scale <- rep(1, nrow(scale.dm))
     }else{
       key.scale <- 1
     }
   }else{
     if(!is.null(ddfobj$scale)){
-      key.scale <- scalevalue(ddfobj$scale$parameters,scale.dm)
+      key.scale <- scalevalue(ddfobj$scale$parameters, scale.dm)
     }
   }
 
   # calculate the key shape
   if(!is.null(ddfobj$shape)){
-    key.shape <- scalevalue(ddfobj$shape$parameters,shape.dm)
+    key.shape <- scalevalue(ddfobj$shape$parameters, shape.dm)
   }
 
   # for gamma shape parameter must be >1, see Becker and Quang (2009) p 213
@@ -169,21 +179,15 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
 
   # 19-Jan-06 jll; added proper standardize code to get std integral.
   #  I left standardize code below in case it is needed for adjustment fcts
-  #
-  # Decide on keyfct.* and run.
-  if(key == "hn"){
-    key.vals <- keyfct.hn(distance, key.scale)
-  }else if(key == "hr"){
-    key.vals <- keyfct.hz(distance, key.scale, key.shape)
-  }else if(key == "unif"){
-    key.vals <- rep(1/width,length(distance))
-  }else if(key == "gamma"){
-    key.vals <- keyfct.gamma(distance, key.scale, key.shape)
-  }else if(key == "th1"){
-    key.vals <- keyfct.th1(distance, key.scale, key.shape)
-  }else if(key == "th2"){
-    key.vals <- keyfct.th2(distance, key.scale, key.shape)
-  }
+
+  # evaluate key function
+  g <- switch(key,
+              hn    = keyfct.hn(distance, key.scale),
+              hr    = keyfct.hz(distance, key.scale, key.shape),
+              unif  = rep(1/(width-left), length(distance)),
+              gamma = keyfct.gamma(distance, key.scale, key.shape),
+              th1   = keyfct.th1(distance, key.scale, key.shape),
+              th2   = keyfct.th2(distance, key.scale, key.shape))
 
   # Adjustment functions
   # If we are using adjustment terms.
@@ -202,60 +206,52 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
     }
 
     ## Decide on adjustment term and run.
-    # If we have simple polynomials
-    if(adj.series == "poly"){
-      adj.vals <- adjfct.poly(distance,scaling,adj.order,adj.parm,adj.exp)
-    # Hermite polynomials
-    }else if(adj.series == "herm"){
-      adj.vals <- adjfct.herm(distance,scaling,adj.order,adj.parm,adj.exp)
-    # Cosine series
-    }else if(adj.series == "cos"){
-      adj.vals <- adjfct.cos(distance,scaling,adj.order,adj.parm,adj.exp)
-    }
+    adj.vals <- switch(adj.series,
+                       poly = adjfct.poly(distance, scaling, adj.order,
+                                          adj.parm, adj.exp),
+                       herm = adjfct.herm(distance, scaling, adj.order,
+                                          adj.parm, adj.exp),
+                       cos  = adjfct.cos(distance, scaling, adj.order,
+                                         adj.parm, adj.exp))
+
+    # calculate detection function with adjustments
+    g <- g * (1 + adj.vals)
 
     # If we have adjustment terms then we need to standardize the detection
     # function. So find the values for the key and adjustment terms at 0
-
-    # dlm 25-Aug-05  This causes a division by zero error in the optimization
-    #    so lets only do it when we need to, it cancels in the
-    #    likelihood anyway.
-    if(standardize == TRUE){
-      if(key == "hn"){
-        key.val.0 <- keyfct.hn(rep(0,length(distance)), key.scale)
-      }else if(key == "hr"){
-        key.val.0 <- keyfct.hz(rep(0,length(distance)), key.scale, key.shape)
-      }else if(key == "gamma"){
+    # this cancels in the likelihood, so we don't need it in optimisation
+    if(standardize){
+      if(key == "gamma"){
         # for the gammma, use apex.gamma to find the apex first, then eval
         # need to update the scale to be +1 in this apex call
         ddfobj$shape$parameters <- log(exp(ddfobj$shape$parameters)+1)
-        g.apex <- as.vector(apex.gamma(ddfobj))[1]
-        key.val.0 <- keyfct.gamma(g.apex,key.scale, key.shape)
-      }else if(key == "unif"){
-        key.val.0 <- rep(1/(width-left),length(distance))
-      }else if(key == "th1"){
-        key.val.0 <- keyfct.th1(rep(0,length(distance)), key.scale, key.shape)
-      }else if(key == "th2"){
-        key.val.0 <- keyfct.th2(rep(0,length(distance)),key.scale, key.shape)
-      }
-      if(adj.series == "poly"){
-        adj.val.0 <- adjfct.poly(rep(0,length(distance)),scaling,
-                                 adj.order,adj.parm,adj.exp)
-      }else if(adj.series == "herm"){
-        adj.val.0 <- adjfct.herm(rep(0,length(distance)),scaling,
-                                 adj.order,adj.parm,adj.exp)
-      }else if(adj.series == "cos"){
-        adj.val.0 <- adjfct.cos(rep(0,length(distance)),scaling,
-                                adj.order,adj.parm,adj.exp)
+        zeros <- as.vector(apex.gamma(ddfobj))[1]
+      }else{
+        zeros <- rep(0, length(distance))
       }
 
-      # Now return the standardized value of the detection function
-      return((key.vals*(1+adj.vals))/(key.val.0*(1+adj.val.0)))
+      key.val.0 <- switch(key,
+                          hn    = keyfct.hn(zeros, key.scale),
+                          hr    = keyfct.hz(zeros, key.scale, key.shape),
+                          unif  = rep(1/(width-left), length(zeros)),
+                          gamma = keyfct.gamma(zeros, key.scale, key.shape),
+                          th1   = keyfct.th1(zeros, key.scale, key.shape),
+                          th2   = keyfct.th2(zeros, key.scale, key.shape))
 
-    }else{
-      return(key.vals*(1+adj.vals))
-    }
-  }else{
-    # If we have no adjustment terms then just return the key value.
-    return(key.vals)
-  }
+      # now compute adjustments
+      zeros <- rep(0, length(distance))
+
+      adj.val.0 <- switch(adj.series,
+                          poly = adjfct.poly(zeros, scaling, adj.order,
+                                             adj.parm, adj.exp),
+                          herm = adjfct.herm(zeros, scaling, adj.order,
+                                             adj.parm, adj.exp),
+                          cos  = adjfct.cos(zeros, scaling, adj.order,
+                                            adj.parm, adj.exp))
+
+      # standardized value of the detection function
+      g <- g/(key.val.0 * (1 + adj.val.0))
+    } # end standardize
+  } # end adjustments
+  return(g)
 }
