@@ -34,10 +34,16 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
 
   width <- misc.options$width
 
+  # set "standardize" to FALSE, as this cancels in the likelihood
+  # evaluation. Note that we it has to be the same value (TRUE/FALSE)
+  # through all computations (for both detection function and integral)
+  # or the below makes no sense
+  standardize <- FALSE
+
   # Compute log-likelihood for any binned data
-  lnl <- rep(0, dim(x)[1])
+  lnl <- rep(0, nrow(x))
   if(any(x$binned)){
-    # Get bins and create unique set of bins/covariates and indices 
+    # Get bins and create unique set of bins/covariates and indices
     # (int.index) in that set
     bins <- as.matrix(x[x$binned, c("distbegin", "distend")])
     allbins <- apply(cbind(bins, z[x$binned, , drop=FALSE]), 1,
@@ -48,25 +54,25 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
 
     int.index <- match(allbins,
                        apply(cbind(bins,
-                              z[x$binned, , drop=FALSE])[uniquevals, , drop=FALSE],
+                              z[x$binned,,drop=FALSE])[uniquevals,,drop=FALSE],
                               1, paste, collapse=""))
 
     which.obs <- x$binned
     which.obs[!uniquevals] <- FALSE
     int.bin <- integratepdf(ddfobj, select=which.obs, width=width,
                             int.range=uniquebins,
-                            standardize=FALSE, point=misc.options$point,
+                            standardize=standardize, point=misc.options$point,
                             left=misc.options$left)
 
     if(any(int.bin<0)){
       int.bin <- integratepdf(ddfobj, select=which.obs, width=width,
                               int.range=uniquebins,
-                              standardize=FALSE, point=misc.options$point,
+                              standardize=standardize, point=misc.options$point,
                               left=misc.options$left)
     }
 
-    if(any(int.bin<=0)){
-      warning("\nProblems with integration. integral <=0. Setting integral to 1E-25\n")
+    if(any(int.bin<=0) && misc.options$showit > 0){
+      warning("\nDetection function integral <=0. Setting integral to 1E-25\n")
       int.bin[int.bin<=0] <- 1E-25
     }
 
@@ -76,7 +82,7 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
     if(ddfobj$intercept.only & samelimits){
       int.all <- integratepdf(ddfobj, select=c(TRUE, rep(FALSE, nrow(x)-1)),
                               width=width,int.range=int.range,
-                              standardize=FALSE,
+                              standardize=standardize,
                               point=misc.options$point, left=misc.options$left)
     }else{
       if(nrow(int.range)==1){
@@ -91,7 +97,7 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
 
       int.index <- match(allbins,
                          apply(cbind(bins,
-                               z[x$binned, , drop=FALSE])[uniquevals, , drop=FALSE],
+                               z[x$binned,,drop=FALSE])[uniquevals,,drop=FALSE],
                                1, paste, collapse=""))
 
       which.obs <- x$binned
@@ -99,7 +105,7 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
 
       int.all <- integratepdf(ddfobj, select=which.obs, width=width,
                               int.range=uniquebins,
-                              standardize=FALSE, point=misc.options$point,
+                              standardize=standardize, point=misc.options$point,
                               left=misc.options$left)
       int.all <- int.all[int.index]
     }
@@ -113,27 +119,27 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
     }
 
     # Negative log-likelihood values for binned data
-    lnl[x$binned] <- -log(int.bin/int.all)
+    lnl[x$binned] <- -(log(int.bin) -log(int.all))
   }
 
   # Compute log-likelihood for any unbinned data
   if(!all(x$binned)){
     p1 <- distpdf(x$distance[!x$binned], ddfobj=ddfobj, select=!x$binned,
-#                  width=width, standardize=FALSE, point=misc.options$point,
-                  width=right, standardize=FALSE, point=misc.options$point,
-                  left=left)
+                  width=right, standardize=standardize,
+                  point=misc.options$point, left=left)
     p1[p1<1.0e-15] <- 1.0e-15
     p1[is.nan(p1)] <- 1.0e-15
+
     # Compute integrals - repeat with doeachint if not set and any 
     # integral values < 0
     int1 <- -1
     i <- 0
-    while (any(int1 < 0) & (i < 2)){
+    while(any(int1 < 0) & (i < 2)){
       if(ddfobj$intercept.only & samelimits){
         int1 <- integratepdf(ddfobj,
                              select=c(TRUE, rep(FALSE, nrow(ddfobj$xmat))),
                              width=width, int.range=int.range,
-                             point=misc.options$point, standardize=FALSE,
+                             point=misc.options$point, standardize=standardize,
                              left=left)
       }else{
         if(nrow(int.range)>1){
@@ -142,35 +148,29 @@ flpt.lnl <- function(fpar, ddfobj, misc.options){
           intrange <- int.range[rep(1, nrow(x)), ]
         }
 
-#        int1 <- integratepdf(ddfobj, select=!x$binned, width=width,
         int1 <- integratepdf(ddfobj, select=!x$binned, width=right,
                              int.range=intrange[!x$binned, ],
-                             point=misc.options$point, standardize=FALSE,
+                             point=misc.options$point, standardize=standardize,
                              left=left)
       }
+
       doeachint <- TRUE
+      # set to -1 to flag above if we get NaNs
+      int1[is.nan(int1)] <- -1
       i <- i + 1
     }
-    if(any(int1<=0)){
-      int1[int1<=0] <- 1e-15
-      warning("\n Problems with integration. integral <=0. Setting integral to 1E-25\n")
-    }
-
-    # Handle some special cases that can occur
-    if(is.vector(left)){
-      int1[is.infinite(int1)] <-  right - left
-      int1[is.nan(int1)] <- right - left
-    }else{
-      int1[is.infinite(int1)] <- right[is.infinite(int1)] -
-                                  left[is.infinite(int1)]
-      int1[is.nan(int1)] <- right[is.nan(int1)] - left[is.nan(int1)]
+    # if the integral is <=0 something Very Bad has happened
+    # but usually we recover as this is just a bad par combination
+    if(any(int1<=0) && misc.options$showit > 0){
+      int1[int1<=0] <- NaN
+      warning("\n Problems with integration (integral <=0).\n")
     }
 
     if(is.matrix(int1) && dim(int1)==c(1, 1)){
       int1 <- as.vector(int1)
     }
     # Negative log-likelihood values for unbinned data
-    lnl[!x$binned] <- -log(p1/int1)
+    lnl[!x$binned] <- -(log(p1) -log(int1))
   }
 
   if(any(is.nan(lnl))){
