@@ -1,32 +1,49 @@
-#' Plot fit of detection functions and histograms of data from distance sampling model
+#' Plot fit of detection functions and histograms of data from distance
+#' sampling model
 #'
-#' Plots the fitted detection function(s) with a histogram of the observed distances to compare visually the fitted model and data.
+#' Plots the fitted detection function(s) with a histogram of the observed
+#' distances to compare visually the fitted model and data.
 #'
-#' The structure of the histogram can be controlled by the user-defined arguments \code{nc} or \code{breaks}. The observation specific detection probabilities along with the line representing the fitted average detection probability.
+#' The structure of the histogram can be controlled by the user-defined
+#' arguments \code{nc} or \code{breaks}. The observation specific detection
+#' probabilities along with the line representing the fitted average detection
+#' probability.
 #'
-#' It is not intended for the user to call \code{plot.ds} but its arguments are documented here. Instead the generic \code{plot} command should be used and it will call the appropriate function based on the class of the \code{ddf} object.
+#' It is not intended for the user to call \code{plot.ds} but its arguments are
+#' documented here. Instead the generic \code{plot} command should be used and
+#' it will call the appropriate function based on the class of the \code{ddf}
+#' object.
 #'
 #' @aliases plot.ds
 #' @export
 #' @param x fitted model from \code{ddf}.
 #' @param which index to specify which plots should be produced:
 #'  \tabular{ll}{1 \tab histogram of observed distances\cr
-#'               2 \tab histogram of observed distances with fitted line and points (default)\cr}
+#'               2 \tab histogram of observed distances with fitted line and
+#'               points (default)\cr}
 #' @param breaks user defined breakpoints
 #' @param nc number of equal width bins for histogram
-#' @param jitter.v apply jitter to points by multiplying the fitted value by a random draw from a normal distribution with mean 1 and sd \code{jitter.v}.
-#' @param showpoints logical variable; if \code{TRUE} plots predicted value for each observation (conditional on its observed distance).
+#' @param jitter.v apply jitter to points by multiplying the fitted value by a
+#' random draw from a normal distribution with mean 1 and sd \code{jitter.v}.
+#' @param showpoints logical variable; if \code{TRUE} plots predicted value for
+#' each observation (conditional on its observed distance).
 #' @param subset subset of data to plot.
 #' @param pl.col colour for histogram bars.
 #' @param pl.den shading density for histogram bars.
 #' @param pl.ang shading angle for histogram bars.
 #' @param main plot title.
 #' @param ylim vertical axis limits.
-#' @param pdf plot the histogram of distances with the PDF of the probability of detection overlaid. Ignored (with warning) for line transect models.
-#' @param pages the number of pages over which to spread the plots. For example, if \code{pages=1} then all plots will be displayed on one page. Default is 0, which prompts the user for the next plot to be displayed.
+#' @param pdf plot the histogram of distances with the PDF of the probability
+#' of detection overlaid. Ignored (with warning) for line transect models.
+#' @param pages the number of pages over which to spread the plots. For
+#' example, if \code{pages=1} then all plots will be displayed on one page.
+#' Default is 0, which prompts the user for the next plot to be displayed.
 #' @param xlab horizontal axis label (defaults to "Distance").
-#' @param ylab vertical axis label (default automatically set depending on plot type).
-#' @param \dots other graphical parameters, passed to the plotting functions (\code{\link{plot}}, \code{\link{hist}}, \code{\link{lines}}, \code{\link{points}}, etc).
+#' @param ylab vertical axis label (default automatically set depending on plot
+#' type).
+#' @param \dots other graphical parameters, passed to the plotting functions
+#' (\code{\link{plot}}, \code{\link{hist}}, \code{\link{lines}},
+#' \code{\link{points}}, etc).
 #' @return Just plots.
 #' @author Jeff Laake, Jon Bishop, David Borchers, David L Miller
 #' @keywords plot
@@ -352,15 +369,28 @@ plot.ds <- function(x, which=2, breaks=NULL, nc=NULL,
       }
     }
 
+    # remove elements of ... which are used in the histogram but don't
+    # make sense for the lines or points next
+    dots <- list(...)
+    dots$border <- NULL
+
     # actually plot the lines
-    lines(xgrid, linevalues, ...)
+    ldots <- dots
+    ldots$x <- xgrid
+    ldots$y <- linevalues
+    #lines(xgrid, linevalues, ...)
+    do.call(lines, ldots)
 
     if(showpoints){
       jitter.p <- rnorm(length(point_vals), 1, jitter.v[1])
-      points(xmat$distance, point_vals*jitter.p, ...)
+      pdots <- dots
+      pdots$x <- xmat$distance
+      pdots$y <- point_vals*jitter.p
+      #points(xmat$distance, point_vals*jitter.p, ...)
+      do.call(points, pdots)
     }
 
-    # use the user-supplied main= ...
+    # use the user-supplied plot title
     if(!is.null(main)){
        title(main, cex.main=0.8)
     }
