@@ -58,7 +58,10 @@ setinitial.ds <- function(ddfobj, width, initial, point, left){
 
   # Set initial values for the adjustment term parameters
   if(!is.null(ddfobj$adjustment)){
-    initialvalues$adjustment <- rep(0, length(ddfobj$adjustment$order))
+    # note that setting to zero causes issues with nlminb optimization
+    # this small value causes problems for solnp, so see detfct.fit.opt
+    # for work-around
+    initialvalues$adjustment <- rep(1e-16, length(ddfobj$adjustment$order))
   }
 
   if(!any(is.na(initial))){
